X-Git-Url: https://git.p6c8.net/jirafeau_project.git/blobdiff_plain/7496abe3c13d938d2da0e8c8a248bc704e9886da..1a41ef82ac7e1a30134e471f73e9a8d0e204f2a6:/index.php
diff --git a/index.php b/index.php
index d03ee81..6c0a03a 100644
--- a/index.php
+++ b/index.php
@@ -35,8 +35,14 @@ if (has_error()) {
require(JIRAFEAU_ROOT . 'lib/template/header.php');
/* Check if user is allowed to upload. */
-// First check: Challenge by IP
-if (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
+// First check: Challenge by IP NO PASSWORD
+if (true === jirafeau_challenge_upload_ip($cfg['upload_ip_nopassword'], get_ip_address($cfg))) {
+ $_SESSION['upload_auth'] = true;
+ $_POST['upload_password'] = '';
+ $_SESSION['user_upload_password'] = $_POST['upload_password'];
+}
+// Second check: Challenge by IP
+elseif (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
// Is an upload password required?
if (jirafeau_has_upload_password($cfg)) {
// Logout action
@@ -101,7 +107,7 @@ else {
-
+
-
+
-
+
-
+